@@ -120,7 +120,7 @@
     <message>
         <location filename="../mainwindow.ui" line="359"/>
         <source>Rename User Account</source>
-        <translation type="unfinished"></translation>
+        <translation>Zmień Nazwę Konta Użytkownika</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="371"/>
@@ -131,7 +131,7 @@
     <message>
         <location filename="../mainwindow.ui" line="403"/>
         <source>New user name:</source>
-        <translation type="unfinished"></translation>
+        <translation>Nowa nazwa użytkownika:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="432"/>
@@ -555,7 +555,7 @@ Wybierz inną nazwę, zanim przejdziesz dalej.</translation>
     <message>
         <location filename="../mainwindow.cpp" line="369"/>
         <source>Sorry, this name is in use. Please enter a different name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Przepraszamy, ta nazwa jest już wykorzystywana. Wybierz inną nazwę.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="374"/>
@@ -621,7 +621,7 @@ Wybierz inną nazwę, zanim przejdziesz dalej.</translation>
     <message>
         <location filename="../mainwindow.cpp" line="479"/>
         <source>Sorry, that group name already exists. Please enter a different name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Przepraszamy, ta nazwa grupy już istnieje. Wybierz inną nazwę.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="486"/>
@@ -661,27 +661,27 @@ Wybierz inną nazwę, zanim przejdziesz dalej.</translation>
     <message>
         <location filename="../mainwindow.cpp" line="539"/>
         <source>The selected user name is currently in use.</source>
-        <translation type="unfinished"></translation>
+        <translation>Wybrana nazwa użytkownika jest już zajęta.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="540"/>
         <source>To rename this user, please log out and log back in using another user account.</source>
-        <translation type="unfinished"></translation>
+        <translation>Aby zmienić nazwę użytkownika, proszę się wylogować i zalogować używając innego konta.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="561"/>
         <source>Sorry, this name already exists on your system. Please enter a different name.</source>
-        <translation type="unfinished"></translation>
+        <translation>Przepraszamy, ta nazwa jest już wykorzystywana. Wybierz inną nazwę.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="569"/>
         <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
-        <translation type="unfinished"></translation>
+        <translation>Nie udało się zmienić nazwy użytkownika. Proszę upewnić się, że użytkownik nie jest zalogowany, może być konieczne ponowne uruchomienie.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="583"/>
         <source>The user was renamed.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nazwa użytkownika została zmieniona.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="595"/>
